<?php

namespace GopNext\Controllers;

use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DTO\Response\Error;
use Zeedhi\Framework\DataSource;
use Zeedhi\Framework\DataSource\DataSet;

class OperatingBudgetParametersController {
    
    protected $service;
    protected $crudService;
    
    public function __construct($connection, $environment, $util, $service, $crudService){
        $this->connection   = $connection;
        $this->environment  = $environment;
        $this->util         = $util;
        $this->service      = $service;
        $this->crudService	= $crudService;
    }
    
    public function operationalItem(Request\DataSet $request, Response $response) {
        $conditions = [];
        $rows = $request->getDataSet()->getRows();
        $operationalItem = $this->crudService->getFilteredDataSet('operationalItem', $conditions)->getRows();
        if(count($operationalItem) == 0){
            $this->insertItems($rows);         
        }
        $data = [];
        $parametersBudgetOperation = $this->service->reciveParametersForBudgetOperation();
        array_push($data, $operationalItem, $parametersBudgetOperation);
        $response->addDataSet(new DataSet("validateOperationalitemsSelect", $data));
    }

    public function insertItems($rows) {
        $this->service->beginTransaction();
        $idCheck = 'S';
        try{
            foreach($rows as $row) {
               switch ($row["value"]) {
                    case 0:
                        $idTipoOrca = "FATURAMENTO";
                        break;
                    case 1:
                        $idTipoOrca = "IMPOSTO";
                        break;
                    case 2:
                        $idTipoOrca = "CONSUMO";
                        break;
                    case 3:
                        $idTipoOrca = "MAOOBRA";
                        break;
                    case 4:
                        $idTipoOrca = "TAXAADM";
                        break;
                    case 5:
                        $idTipoOrca = "DESPMATRIZ";
                        break;
                    case 6:
                        $idTipoOrca = "DESPDIVERSA";
                        break;
                    case 7:
                        $idTipoOrca = "DESPENTRADA";
                        break;
                    case 8:
                        $idTipoOrca = "IMPOSTOARECUPERAR";
                        break;
                    case 9:
                        $idTipoOrca = "IMPOSTOSOBLUCRO";
                        break;
                    case 10:
                        $idTipoOrca = "INVESTIMENTO";
                        break;
                    case 11:
                        $idTipoOrca = "DEPRECIACAO";
                        break;
                }
                $params = [
                    "NRITEMOPERACIONAL"   => $row["value"],
                    "IDCHECK"             => $idCheck,
                    "IDTIPOORCAOP"        => $idTipoOrca
                ];
                $this->service->insertOperationalItem($params); 
            }
            $this->service->commit();
        }catch(Exception $e) {
            $this->service->rollback();
            throw $e;
        }   
    }
    
    public function saveBudgetOperation(Request\Row $request, Response $response) {
        $row = $request->getRow();
        try {
            $this->service->beginTransaction();
    
            $params = [
                "IDTIPOSIMULARESULTFAT" => $row["IDTIPOSIMULARESULTFAT"],
                "IDUTILMESBASE" => $row["IDUTILMESBASE"],
                "CDTIPOCUSTO" => $row["CDTIPOCUSTO"],
                "CDTOINDICECON" => $row["CDTOINDICECON"],
                "CDINDICEFAT" => $row["CDINDICEFAT"],
                "IDORCDESPDIVERS" => $row["IDORCDESPDIVERS"],
                "IDORCADESPMATRI" => $row["IDORCADESPMATRI"],
                "IDORCDESPENTROP" => $row["IDORCDESPENTROP"],
                "NRDIALIMITEORCA" => $row["NRDIALIMITEORCA"],
                "IDPERORCAITEMDETAL" => $row["IDPERORCAITEMDETAL"],
                "IDUTILVERSAOORCA" => $row["IDUTILVERSAOORCA"],
                "IDAPROVORCACONC" => $row["IDAPROVORCACONC"],
                "IDCALCFATUROP" => $row["IDCALCFATUROP"],
                "NRDIAANTELABORCA" => $row["NRDIAANTELABORCA"],
                "IDUTILORCAREALOC" => $row["IDUTILORCAREALOC"],
                "IDCONSORCREALOC" => $row["IDCONSORCREALOC"],
                "IDPERIODOORCA" => $row["IDPERIODOORCA"],
                "IDREALINFORCA" => $row["IDREALINFORCA"],
                "IDREALSUPORCA" => $row["IDREALSUPORCA"],
                "NRDIAINIORCA" => $row["NRDIAINIORCA"],
                "NRMESINIORCA" => $row["NRMESINIORCA"]
            ];
            $this->service->updateBudgetOperation($params);

            $this->service->commit();
        } catch (\Exception $ex) {
            $this->service->rollback();
            $response->setError(new Error($ex->getMessage(), 500));
        }
    }
    
    public function populateDatasourceGrid(Request\Filter $request, Response $response) {
        $params = ['CDOPERADOR' ];
        $conditions = $this->util->prepareConditions($params);
        array_push($conditions, array(
                "columnName" => "IDCNTRRESC",
                "operator"   => '=',
                "value"      => 'T'
            ));
        $data = $this->crudService->getFilteredDataSet('filioper', $conditions)->getRows();
    	$response->addDataSet(new DataSet("populateDatasourceGrid", $data));
    }
    
    public function populateFormUnit(Request\Row $request, Response $response) {
        $row = $request->getRow();
        $params = ['NRORG'];
        $conditions = $this->util->prepareConditions($params);
        array_push($conditions, array(
                "columnName" => "CDFILIAL",
                "operator" => "=",
                "value" =>  $row["CDFILIAL"]
        ));
        $data = $this->crudService->getFilteredDataSet('operatingUnit', $conditions)->getRows();
    	$response->addDataSet(new DataSet("operatingUnit", $data));
    }
}