import Vue from 'vue';
import { ZdFieldGroup } from '@zeedhi/zd-field-group';
import {
  Http,
  Metadata,
  IEventParam,
} from '@zeedhi/core';
import {
  SelectMultiple,
  Select,
  Form,
  Checkbox,
  Grid,
} from '@zeedhi/common';

Vue.component('ZdFieldGroup', ZdFieldGroup);

export class OperatingBudgetParametersController {
  public checkInvalue() {
    const formBudgetCycle = Metadata.getInstance<Form>('budgetCycleForm');
    const checkboxValue = formBudgetCycle.getChildInstance<Checkbox>('IDUTILORCAREALOC').value;

    formBudgetCycle.getChildInstance<Checkbox>('IDCONSORCREALOC').disabled = checkboxValue !== 'S';
    formBudgetCycle.getChildInstance<Select>('IDREALSUPORCA').disabled = checkboxValue !== 'S';
    formBudgetCycle.getChildInstance<Select>('IDREALINFORCA').disabled = checkboxValue !== 'S';
  }
  
  public validateGeneralFields() {
    const arrayValue = [];
    const operationalItem = Metadata.getInstance<SelectMultiple>('OperationalitemsSelect');
    Http.post('/operationalItem', {
      requestType: 'DataSet',
      dataset: operationalItem.datasource.data,
    }).then((response) => {
      const data = response.data.dataset.validateOperationalitemsSelect;
      this.reciveBudgetOperation(data[1][0]);
      data[0].forEach((row) => {
        arrayValue.push(row.NRITEMOPERACIONAL);
      });
      operationalItem.setValue(arrayValue);
    });
  }
  
  public reciveBudgetOperation(data) {
    const formIndexContractCorrection = Metadata.getInstance<Form>('indexContractCorrectionForm');
    const formCalculationConsumption = Metadata.getInstance<Form>('calculationConsumptionForm');
    const formResultSimulation = Metadata.getInstance<Form>('resultSimulationBasedForm');
    const formBudgetDetailing = Metadata.getInstance<Form>('budgetDetailForm');
    const formProfile = Metadata.getInstance<Form>('formBillingCalculation');
    const formBudgetCycle = Metadata.getInstance<Form>('budgetCycleForm');
    
    formProfile.value.IDPERORCAITEMDETAL = data.IDPERORCAITEMDETAL;
    formProfile.value.IDUTILVERSAOORCA = data.IDUTILVERSAOORCA;
    formProfile.value.IDAPROVORCACONC = data.IDAPROVORCACONC;
    formProfile.value.IDCALCFATUROP = data.IDCALCFATUROP;
    
    formBudgetDetailing.value.IDORCDESPDIVERS = data.IDORCDESPDIVERS;
    formBudgetDetailing.value.IDORCADESPMATRI = data.IDORCADESPMATRI;
    formBudgetDetailing.value.IDORCDESPENTROP = data.IDORCDESPENTROP;
    formBudgetDetailing.value.NRDIALIMITEORCA = data.NRDIALIMITEORCA;
    
    formBudgetCycle.value.NRDIAANTELABORCA = data.NRDIAANTELABORCA;
    formBudgetCycle.value.IDUTILORCAREALOC = data.IDUTILORCAREALOC;
    formBudgetCycle.value.IDCONSORCREALOC = data.IDCONSORCREALOC;
    formBudgetCycle.value.IDPERIODOORCA = data.IDPERIODOORCA;
    formBudgetCycle.value.IDREALINFORCA = data.IDREALINFORCA;
    formBudgetCycle.value.IDREALSUPORCA = data.IDREALSUPORCA;
    formBudgetCycle.value.NRDIAINIORCA = data.NRDIAINIORCA;
    formBudgetCycle.value.NRMESINIORCA = data.NRMESINIORCA;
    
    formResultSimulation.value.IDTIPOSIMULARESULTFAT = data.IDTIPOSIMULARESULTFAT;
    formIndexContractCorrection.value.CDTOINDICECON = data.CDTOINDICECON;
    formIndexContractCorrection.value.CDINDICEFAT = data.CDINDICEFAT;
    formCalculationConsumption.value.IDUTILMESBASE = data.IDUTILMESBASE;
    formCalculationConsumption.value.CDTIPOCUSTO = data.CDTIPOCUSTO;

    this.checkInvalue();
  }
  
  public saveBudgetOperation() {
    const formCalculationConsumption = Metadata.getInstance<Form>('calculationConsumptionForm');
    const formResultSimulation = Metadata.getInstance<Form>('resultSimulationBasedForm');
    const formIndexContract = Metadata.getInstance<Form>('indexContractCorrectionForm');
    const formBudgetDetailing = Metadata.getInstance<Form>('budgetDetailForm');
    const formProfile = Metadata.getInstance<Form>('formBillingCalculation');
    const formBudgetCycle = Metadata.getInstance<Form>('budgetCycleForm');
    
    const sendObject = {
      IDTIPOSIMULARESULTFAT: formResultSimulation.value.IDTIPOSIMULARESULTFAT,
      IDUTILMESBASE: formCalculationConsumption.value.IDUTILMESBASE,
      CDTIPOCUSTO: formCalculationConsumption.value.CDTIPOCUSTO,
      CDTOINDICECON: formIndexContract.value.CDTOINDICECON,
      CDINDICEFAT: formIndexContract.value.CDINDICEFAT,

      IDORCDESPDIVERS: formBudgetDetailing.value.IDORCDESPDIVERS,
      IDORCADESPMATRI: formBudgetDetailing.value.IDORCADESPMATRI,
      IDORCDESPENTROP: formBudgetDetailing.value.IDORCDESPENTROP,
      NRDIALIMITEORCA: formBudgetDetailing.value.NRDIALIMITEORCA,

      IDPERORCAITEMDETAL: formProfile.value.IDPERORCAITEMDETAL,
      IDUTILVERSAOORCA: formProfile.value.IDUTILVERSAOORCA,
      IDAPROVORCACONC: formProfile.value.IDAPROVORCACONC,
      IDCALCFATUROP: formProfile.value.IDCALCFATUROP,

      NRDIAANTELABORCA: formBudgetCycle.value.NRDIAANTELABORCA,
      IDUTILORCAREALOC: formBudgetCycle.value.IDUTILORCAREALOC,
      IDCONSORCREALOC: formBudgetCycle.value.IDCONSORCREALOC,
      IDPERIODOORCA: formBudgetCycle.value.IDPERIODOORCA,
      IDREALINFORCA: formBudgetCycle.value.IDREALINFORCA,
      IDREALSUPORCA: formBudgetCycle.value.IDREALSUPORCA,
      NRDIAINIORCA: formBudgetCycle.value.NRDIAINIORCA,
      NRMESINIORCA: formBudgetCycle.value.NRMESINIORCA,

    };
 
    Http.post('/saveBudgetOperation', {
      requestType: 'Row',
      row: sendObject,
    });
  }
  
  public populateDatasourceGrid() {
    const grid = Metadata.getInstance<Grid>('gridUnit');
    Http.get('/populateDatasourceGrid').then((response) => {
      const data = response.data.dataset.populateDatasourceGrid;
      grid.datasource.updateData(data);
    });
  }
  
  public populateFormUnit(row) {
    const sendObject = {
      CDFILIAL: row.CDFILIAL,
    };
    Http.post('/populateFormUnit', {
      requestType: 'Row',
      row: sendObject,
    }).then((response) => {
      const data = response.data.dataset.populateFormUnit;
      this.reciveFormUnit(data[0]);
    });
  }
  
  public reciveFormUnit(data) {
    const formUnit = Metadata.getInstance<Form>('formUnit');
    
    formUnit.value.NRMESREAJCONTR = data.NRMESREAJCONTR;
    formUnit.value.VRPEORCBLOQFIL = data.VRPEORCBLOQFIL;
    formUnit.value.VRPEORCALERTFIL = data.VRPEORCALERTFIL;
    formUnit.value.IDCALCOMESTORC = data.IDCALCOMESTORC;
    formUnit.value.IDCONSAPENCARDAPROV = data.IDCONSAPENCARDAPROV;
    formUnit.value.NRDIAINIORCAGOP = data.NRDIAINIORCAGOP;
    formUnit.value.IDUTILPERCFILGOP = data.IDUTILPERCFILGOP;
  }
  
  public form?: Form;

  public loadFormInstance() {
    this.form = Metadata.getInstance<Form>('formUnit');
  }

  public formVisible = false;

  public get visibleCardGrid() {
    return !this.formVisible;
  }

  public clickVisibleControll() {
    this.form!.clearForm();
    this.formVisible = false;
  }

  public async clickRowGrid({ row }: IEventParam<Grid>) {
    // this.populateFormUnit(row);
    this.formVisible = true;
    this.form!.value = {
      codeUnit: row.CDFILIAL,
      nameUnit: row.NMFILIAL,
    };
  }
}
